@@ -1,6 +1,6 @@
 import random
 import json
-import urllib.requests
+import urllib.request
 def advice(display):
   try:
     display = bool(display)
